@@ -34,7 +34,10 @@ class client():
                     except ConnectionError as ex: # todo use specified exception type
                         print(str(ex))
                         if self.received:
-                            self.received('disconnected')
+                            if inspect.iscoroutinefunction(self.received):
+                                await self.received('disconnected')
+                            else:
+                                self.received('disconnected')
                         break
                 print('Close the socket')
                 if failed!=None:
@@ -44,7 +47,7 @@ class client():
                 await asyncio.sleep(10)
                 print('trying to reconnect...')
             except Exception as Ex: # todo get the relevant exceptions: TimeoutError
-                print('failed to connect')
+                print(f'failed to connect:{Ex}')
                 if failed!=None:
                     failed(serverHost)
                     break
