@@ -61,8 +61,8 @@ class Node():
                 self.__setitem__(key, value)
 
 class control:
-    def __init__(self, nodename='control', inputs='', outputs='', handler = None):
-        self.nw = NodeWire(nodename, process=self.process)
+    def __init__(self, nodename='control', inputs='', outputs='', handler = None, server = 'secure.nodewire.org'):
+        self.nw = NodeWire(nodename, process=self.process, server = server)
         self.nw.debug = False
         self.nodes = []
         self.sender = None
@@ -111,7 +111,7 @@ class control:
                 self.nw.send('re', 'portvalue', key, json.dumps(value))
 
     def __getattr__(self, item):
-        if item in ['nw', 'nodes', 'sender', 'inputs', 'outputs']:
+        if item in ['nw', 'nodes', 'sender', 'inputs', 'outputs', 'queue']:
             return super(control, self).__getattr__(item)
         ports = [p for p in self.inputs if p['port']==item]
         if ports != []:
@@ -121,7 +121,7 @@ class control:
             return self.get(item)
 
     def __setattr__(self, key, value):
-        if key in ['nw', 'nodes', 'sender', 'inputs', 'outputs']:
+        if key in ['nw', 'nodes', 'sender', 'inputs', 'outputs', 'queue']:
             super(control, self).__setattr__(key, value)
         else:
             if key.startswith('on_'):
@@ -216,7 +216,7 @@ class control:
             if nodename in will_get:
                 will_get[nodename](n)
                 del will_get[nodename]
-                if self.queue: self.queue.put_nowait(n)
+            if self.queue: self.queue.put_nowait(n)
 
 
 if __name__ == '__main__':
